@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-view.c 5931 2007-09-25 20:05:40Z pborelli $ 
+ * $Id: gedit-view.c 6133 2008-01-27 15:02:26Z pborelli $ 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -590,11 +590,20 @@ gedit_view_set_font (GeditView   *view,
 	g_return_if_fail (GEDIT_IS_VIEW (view));
 
 	if (def)
-		font_name = gedit_prefs_manager_get_system_font ();
+	{
+		gchar *font;
 
-	g_return_if_fail (font_name != NULL);
+		font = gedit_prefs_manager_get_system_font ();
+		font_desc = pango_font_description_from_string (font);
+		g_free (font);
+	}
+	else
+	{
+		g_return_if_fail (font_name != NULL);
+
+		font_desc = pango_font_description_from_string (font_name);
+	}
 
-	font_desc = pango_font_description_from_string (font_name);
 	g_return_if_fail (font_desc != NULL);
 
 	gtk_widget_modify_font (GTK_WIDGET (view), font_desc);
@@ -873,6 +882,9 @@ hide_search_window (GeditView *view, gboolean cancel)
 		
 		gedit_view_scroll_to_cursor (view);
 	}
+
+	/* make sure a focus event is sent for the edit area */
+	send_focus_change (GTK_WIDGET (view), TRUE);
 }
 
 static gboolean
