@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window-private.h,v 1.3 2005/12/14 17:25:12 pborelli Exp $
+ * $Id: gedit-window-private.h 5811 2007-08-15 12:18:40Z pborelli $
  */
 
 #ifndef __GEDIT_WINDOW_PRIVATE_H__
@@ -33,7 +33,6 @@
 
 #include "gedit/gedit-window.h"
 #include "gedit-prefs-manager.h"
-#include "recent-files/egg-recent-view-uimanager.h"
 
 G_BEGIN_DECLS
 
@@ -66,11 +65,14 @@ struct _GeditWindowPrivate
 	GtkWidget      *toolbar_recent_menu;
 	GeditToolbarSetting toolbar_style;
 
-	EggRecentViewUIManager *recent_view_uim;
+	/* recent files */
+	GtkActionGroup *recents_action_group;
+	guint           recents_menu_ui_id;
+	gulong          recents_handler_id;
 
 	GeditTab       *active_tab;
 	gint            num_tabs;
-	
+
 	gint            num_tabs_with_error;
 
 	gint            width;
@@ -80,13 +82,14 @@ struct _GeditWindowPrivate
 	gint		side_panel_size;
 	gint		bottom_panel_size;
 
-	gboolean	removing_tabs;
-	
 	GeditWindowState state;
 
 	GtkWindowGroup *window_group;
-	
+
 	gchar          *default_path;
+
+	gboolean	removing_tabs : 1;
+	gboolean	destroy_has_run : 1;
 };
 
 G_END_DECLS
