@@ -1,13 +1,13 @@
 /*
  * gedit-time-plugin.c
- * 
+ *
  * Copyright (C) 2002-2005 - Paolo Maggi
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -17,15 +17,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: gedit-time-plugin.c 5785 2007-08-12 11:43:41Z vgeddes $
+ * $Id: gedit-time-plugin.c 6028 2007-12-22 16:07:19Z pborelli $
  */
 
 /*
- * Modified by the gedit Team, 2002. See the AUTHORS file for a 
- * list of people on the gedit Team.  
- * See the ChangeLog files for a list of changes. 
+ * Modified by the gedit Team, 2002. See the AUTHORS file for a
+ * list of people on the gedit Team.
+ * See the ChangeLog files for a list of changes.
  */
- 
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -34,79 +34,33 @@
 #include <time.h>
 
 #include <gconf/gconf-client.h>
-#include <libgnome/gnome-config.h>
 
 #include "gedit-time-plugin.h"
 #include <gedit/gedit-help.h>
 
 #include <glib/gi18n-lib.h>
+#include <glib.h>
 #include <gmodule.h>
 
 #include <gedit/gedit-debug.h>
 #include <gedit/gedit-utils.h>
 
-#define GEDIT_TIME_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_TIME_PLUGIN, GeditTimePluginPrivate))
+#define GEDIT_TIME_PLUGIN_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), \
+					      GEDIT_TYPE_TIME_PLUGIN, \
+					      GeditTimePluginPrivate))
 
 #define WINDOW_DATA_KEY "GeditTimePluginWindowData"
 #define MENU_PATH "/MenuBar/EditMenu/EditOps_4"
 
-#define TIME_BASE_KEY 	"/apps/gedit-2/plugins/time"
-#define SELECTED_FORMAT_KEY "/selected_format"
-#define PROMPT_TYPE_KEY "/prompt_type"
-#define CUSTOM_FORMAT_KEY "/custom_format"
-
-#define DIALOG_PROMPT_TYPE_KEY "gedit-2/time_plugin/prompt_type"
+/* gconf keys */
+#define TIME_BASE_KEY		"/apps/gedit-2/plugins/time"
+#define PROMPT_TYPE_KEY		TIME_BASE_KEY "/prompt_type"
+#define SELECTED_FORMAT_KEY	TIME_BASE_KEY "/selected_format"
+#define CUSTOM_FORMAT_KEY	TIME_BASE_KEY "/custom_format"
 
 #define DEFAULT_CUSTOM_FORMAT "%d/%m/%Y %H:%M:%S"
 
-enum
-{
-	COLUMN_FORMATS = 0,
-	COLUMN_INDEX,
-	NUM_COLUMNS
-};
-
-typedef struct _TimeConfigureDialog TimeConfigureDialog;
-
-struct _TimeConfigureDialog
-{
-	GtkWidget *dialog;
-
-	GtkWidget *list;
-	
-        /* Radio buttons to indicate what should be done */
-        GtkWidget *prompt;
-        GtkWidget *use_list;
-        GtkWidget *custom;
-        
-        GtkWidget *custom_entry;
-	GtkWidget *custom_format_example;
-
-	/* Info needed for the response handler */
-	GeditTimePlugin *plugin;	
-};
-
-typedef struct _ChooseFormatDialog ChooseFormatDialog;
-
-struct _ChooseFormatDialog
-{
-	GtkWidget *dialog;
-
-	GtkWidget *list;
-	
-        /* Radio buttons to indicate what should be done */
-        GtkWidget *use_list;
-        GtkWidget *custom;
-        
-        GtkWidget *custom_entry;
-	GtkWidget *custom_format_example;
-	
-	/* Info needed for the response handler */
-	GtkTextBuffer   *buffer;
-	GeditTimePlugin *plugin;
-};
-
-static gchar *formats[] =
+static const gchar *formats[] =
 {
 	"%c",
 	"%x",
@@ -142,21 +96,64 @@ static gchar *formats[] =
 	NULL
 };
 
-typedef enum 
+enum
 {
-	PROMPT_FOR_FORMAT = 0,
-	USE_SELECTED_FORMAT,
-	USE_CUSTOM_FORMAT
+	COLUMN_FORMATS = 0,
+	COLUMN_INDEX,
+	NUM_COLUMNS
+};
+
+typedef struct _TimeConfigureDialog TimeConfigureDialog;
+
+struct _TimeConfigureDialog
+{
+	GtkWidget *dialog;
+
+	GtkWidget *list;
+
+        /* Radio buttons to indicate what should be done */
+        GtkWidget *prompt;
+        GtkWidget *use_list;
+        GtkWidget *custom;
+
+	GtkWidget *custom_entry;
+	GtkWidget *custom_format_example;
+
+	/* Info needed for the response handler */
+	GeditTimePlugin *plugin;
+};
+
+typedef struct _ChooseFormatDialog ChooseFormatDialog;
+
+struct _ChooseFormatDialog
+{
+	GtkWidget *dialog;
+
+	GtkWidget *list;
+
+        /* Radio buttons to indicate what should be done */
+        GtkWidget *use_list;
+        GtkWidget *custom;
+
+        GtkWidget *custom_entry;
+	GtkWidget *custom_format_example;
+
+	/* Info needed for the response handler */
+	GtkTextBuffer   *buffer;
+	GeditTimePlugin *plugin;
+};
+
+typedef enum
+{
+	PROMPT_SELECTED_FORMAT = 0,	/* Popup dialog with list preselected */
+	PROMPT_CUSTOM_FORMAT,		/* Popup dialog with entry preselected */
+	USE_SELECTED_FORMAT,		/* Use selected format directly */
+	USE_CUSTOM_FORMAT		/* Use custom format directly */
 } GeditTimePluginPromptType;
 
 struct _GeditTimePluginPrivate
 {
 	GConfClient *gconf_client;
-	
-	gchar *last_custom_format;
-	gchar *last_selected_format;
-	
-	GeditTimePluginPromptType last_prompt_type;	
 };
 
 GEDIT_PLUGIN_REGISTER_TYPE(GeditTimePlugin, gedit_time_plugin)
@@ -177,13 +174,13 @@ static void time_cb (GtkAction *action, ActionData *data);
 
 static const GtkActionEntry action_entries[] =
 {
-	{ 
+	{
 		"InsertDateAndTime",
 		NULL,
 		N_("In_sert Date and Time..."),
 		NULL,
 		N_("Insert current date and time at the cursor position"),
-		G_CALLBACK (time_cb) 
+		G_CALLBACK (time_cb)
 	},
 };
 
@@ -191,7 +188,7 @@ static void
 gedit_time_plugin_init (GeditTimePlugin *plugin)
 {
 	gedit_debug_message (DEBUG_PLUGINS, "GeditTimePlugin initializing");
-	
+
 	plugin->priv = GEDIT_TIME_PLUGIN_GET_PRIVATE (plugin);
 
 	plugin->priv->gconf_client = gconf_client_get_default ();
@@ -200,8 +197,6 @@ gedit_time_plugin_init (GeditTimePlugin *plugin)
 			      TIME_BASE_KEY,
 			      GCONF_CLIENT_PRELOAD_ONELEVEL,
 			      NULL);
-			      
-	plugin->priv->last_prompt_type = gnome_config_get_int (DIALOG_PROMPT_TYPE_KEY "=1");			      
 }
 
 static void
@@ -212,15 +207,9 @@ gedit_time_plugin_finalize (GObject *object)
 	gedit_debug_message (DEBUG_PLUGINS, "GeditTimePlugin finalizing");
 
 	gconf_client_suggest_sync (plugin->priv->gconf_client, NULL);
-	
+
 	g_object_unref (G_OBJECT (plugin->priv->gconf_client));
-	
-	g_free (plugin->priv->last_custom_format);
-	g_free (plugin->priv->last_selected_format);
-	
-	gnome_config_set_int (DIALOG_PROMPT_TYPE_KEY, plugin->priv->last_prompt_type);
-	gnome_config_sync ();
-	
+
 	G_OBJECT_CLASS (gedit_time_plugin_parent_class)->finalize (object);
 }
 
@@ -245,7 +234,7 @@ update_ui_real (GeditWindow  *window,
 	view = gedit_window_get_active_view (window);
 
 	gedit_debug_message (DEBUG_PLUGINS, "View: %p", view);
-	
+
 	action = gtk_action_group_get_action (data->action_group,
 					      "InsertDateAndTime");
 	gtk_action_set_sensitive (action,
@@ -260,21 +249,21 @@ impl_activate (GeditPlugin *plugin,
 	GtkUIManager *manager;
 	WindowData *data;
 	ActionData *action_data;
-	
+
 	gedit_debug (DEBUG_PLUGINS);
 
 	data = g_new (WindowData, 1);
 	action_data = g_new (ActionData, 1);
-	
+
 	action_data->plugin = GEDIT_TIME_PLUGIN (plugin);
 	action_data->window = window;
-	
+
 	manager = gedit_window_get_ui_manager (window);
 
 	data->action_group = gtk_action_group_new ("GeditTimePluginActions");
-	gtk_action_group_set_translation_domain (data->action_group, 
+	gtk_action_group_set_translation_domain (data->action_group,
 						 GETTEXT_PACKAGE);
-	gtk_action_group_add_actions_full (data->action_group, 
+	gtk_action_group_add_actions_full (data->action_group,
 				      	   action_entries,
 				      	   G_N_ELEMENTS (action_entries),
 				      	   action_data,
@@ -284,17 +273,17 @@ impl_activate (GeditPlugin *plugin,
 
 	data->ui_id = gtk_ui_manager_new_merge_id (manager);
 
-	g_object_set_data_full (G_OBJECT (window), 
-				WINDOW_DATA_KEY, 
+	g_object_set_data_full (G_OBJECT (window),
+				WINDOW_DATA_KEY,
 				data,
 				(GDestroyNotify) free_window_data);
 
-	gtk_ui_manager_add_ui (manager, 
-			       data->ui_id, 
+	gtk_ui_manager_add_ui (manager,
+			       data->ui_id,
 			       MENU_PATH,
-			       "InsertDateAndTime", 
 			       "InsertDateAndTime",
-			       GTK_UI_MANAGER_MENUITEM, 
+			       "InsertDateAndTime",
+			       GTK_UI_MANAGER_MENUITEM,
 			       FALSE);
 
 	update_ui_real (window, data);
@@ -334,28 +323,28 @@ impl_update_ui	(GeditPlugin *plugin,
 	update_ui_real (window, data);
 }
 
+/* whether we should prompt the user or use the specified format */
 static GeditTimePluginPromptType
 get_prompt_type (GeditTimePlugin *plugin)
 {
 	gchar *prompt_type;
 	GeditTimePluginPromptType res;
-	       	
+
 	prompt_type = gconf_client_get_string (plugin->priv->gconf_client,
-			        TIME_BASE_KEY PROMPT_TYPE_KEY,
-				NULL);
+			        	       PROMPT_TYPE_KEY,
+					       NULL);
 
 	if (prompt_type == NULL)
-		return PROMPT_FOR_FORMAT;
+		return PROMPT_SELECTED_FORMAT;
 
 	if (strcmp (prompt_type, "USE_SELECTED_FORMAT") == 0)
 		res = USE_SELECTED_FORMAT;
-	else 
-	{
-		if  (strcmp (prompt_type, "USE_CUSTOM_FORMAT") == 0)
-			res = USE_CUSTOM_FORMAT;
-		else
-			res = PROMPT_FOR_FORMAT;
-	}
+	else if (strcmp (prompt_type, "USE_CUSTOM_FORMAT") == 0)
+		res = USE_CUSTOM_FORMAT;
+	else if (strcmp (prompt_type, "PROMPT_CUSTOM_FORMAT") == 0)
+		res = PROMPT_CUSTOM_FORMAT;
+	else
+		res = PROMPT_SELECTED_FORMAT;
 
 	g_free (prompt_type);
 
@@ -369,10 +358,11 @@ set_prompt_type (GeditTimePlugin           *plugin,
 	const gchar * str;
 
 	if (!gconf_client_key_is_writable (plugin->priv->gconf_client,
-					   TIME_BASE_KEY PROMPT_TYPE_KEY, 
+					   PROMPT_TYPE_KEY,
 					   NULL))
+	{
 		return;
-					 
+	}
 
 	switch (prompt_type)
 	{
@@ -382,29 +372,30 @@ set_prompt_type (GeditTimePlugin           *plugin,
 		case USE_CUSTOM_FORMAT:
 			str = "USE_CUSTOM_FORMAT";
 			break;
+		case PROMPT_CUSTOM_FORMAT:
+			str = "PROMPT_CUSTOM_FORMAT";
+			break;
 		default:
-			str = "PROMPT_FOR_FORMAT";
+			str = "PROMPT_SELECTED_FORMAT";
 	}
-	
-	gconf_client_set_string (plugin->priv->gconf_client, 
-				 TIME_BASE_KEY PROMPT_TYPE_KEY,
-		       		 str, 
+
+	gconf_client_set_string (plugin->priv->gconf_client,
+				 PROMPT_TYPE_KEY,
+		       		 str,
 		       		 NULL);
 }
-	
+
+/* The selected format in the list */
 static gchar *
 get_selected_format (GeditTimePlugin *plugin)
 {
 	gchar *sel_format;
-		       	
-	sel_format = gconf_client_get_string (plugin->priv->gconf_client,
-			        	      TIME_BASE_KEY SELECTED_FORMAT_KEY,
-			        	      NULL);
-			        	      
-	if (sel_format == NULL)
-		return g_strdup (formats [0]);
 
-	return sel_format;
+	sel_format = gconf_client_get_string (plugin->priv->gconf_client,
+					      SELECTED_FORMAT_KEY,
+					      NULL);
+
+	return sel_format ? sel_format : g_strdup (formats [0]);
 }
 
 static void
@@ -412,31 +403,31 @@ set_selected_format (GeditTimePlugin *plugin,
 		     const gchar     *format)
 {
 	g_return_if_fail (format != NULL);
-	
-	if (!gconf_client_key_is_writable (plugin->priv->gconf_client, 
-					   TIME_BASE_KEY SELECTED_FORMAT_KEY, 
+
+	if (!gconf_client_key_is_writable (plugin->priv->gconf_client,
+					   SELECTED_FORMAT_KEY,
 					   NULL))
+	{
 		return;
-		
-	gconf_client_set_string (plugin->priv->gconf_client, 
-				 TIME_BASE_KEY SELECTED_FORMAT_KEY,
-		       		 format, 
+	}
+
+	gconf_client_set_string (plugin->priv->gconf_client,
+				 SELECTED_FORMAT_KEY,
+		       		 format,
 		       		 NULL);
 }
 
+/* the custom format in the entry */
 static gchar *
 get_custom_format (GeditTimePlugin *plugin)
 {
 	gchar *format;
-	       	
+
 	format = gconf_client_get_string (plugin->priv->gconf_client,
-			        	  TIME_BASE_KEY CUSTOM_FORMAT_KEY,
-			        	  NULL);
+					  CUSTOM_FORMAT_KEY,
+					  NULL);
 
-	if (format == NULL)
-		return g_strdup (DEFAULT_CUSTOM_FORMAT);
-
-	return format;
+	return format ? format : g_strdup (DEFAULT_CUSTOM_FORMAT);
 }
 
 static void
@@ -446,13 +437,13 @@ set_custom_format (GeditTimePlugin *plugin,
 	g_return_if_fail (format != NULL);
 
 	if (!gconf_client_key_is_writable (plugin->priv->gconf_client,
-					   TIME_BASE_KEY CUSTOM_FORMAT_KEY, 
+					   CUSTOM_FORMAT_KEY,
 					   NULL))
 		return;
 
-	gconf_client_set_string (plugin->priv->gconf_client, 
-				 TIME_BASE_KEY CUSTOM_FORMAT_KEY,
-		       		 format, 
+	gconf_client_set_string (plugin->priv->gconf_client,
+				 CUSTOM_FORMAT_KEY,
+		       		 format,
 		       		 NULL);
 }
 
@@ -474,24 +465,25 @@ get_time (const gchar* format)
 		return g_strdup (" ");
 
 	locale_format = g_locale_from_utf8 (format, -1, NULL, NULL, NULL);
-	
 	if (locale_format == NULL)
 		return g_strdup (" ");
-		
+
   	clock = time (NULL);
   	now = localtime (&clock);
-	  	
+
 	do
 	{
 		out_length += 255;
 		out = g_realloc (out, out_length);
 	}
   	while (strftime (out, out_length, locale_format, now) == 0);
-  	
+
 	g_free (locale_format);
 
 	if (g_utf8_validate (out, -1, NULL))
+	{
 		out_utf8 = out;
+	}
 	else
 	{
 		out_utf8 = g_locale_to_utf8 (out, -1, NULL, NULL, NULL);
@@ -500,23 +492,22 @@ get_time (const gchar* format)
 		if (out_utf8 == NULL)
 			out_utf8 = g_strdup (" ");
 	}
-	
+
   	return out_utf8;
 }
 
 static void
-dialog_destroyed (GtkObject *obj,  gpointer dialog_pointer)
+dialog_destroyed (GtkObject *obj, gpointer dialog_pointer)
 {
 	gedit_debug (DEBUG_PLUGINS);
-	
+
 	g_free (dialog_pointer);
 
 	gedit_debug_message (DEBUG_PLUGINS, "END");
-	
 }
 
 static GtkTreeModel *
-create_model (GtkWidget       *listview, 
+create_model (GtkWidget       *listview,
 	      const gchar     *sel_format,
 	      GeditTimePlugin *plugin)
 {
@@ -524,7 +515,6 @@ create_model (GtkWidget       *listview,
 	GtkListStore *store;
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
-	gchar *sf;
 
 	gedit_debug (DEBUG_PLUGINS);
 
@@ -532,9 +522,8 @@ create_model (GtkWidget       *listview,
 	store = gtk_list_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_INT);
 
 	/* Set tree view model*/
-	gtk_tree_view_set_model (GTK_TREE_VIEW (listview), 
+	gtk_tree_view_set_model (GTK_TREE_VIEW (listview),
 				 GTK_TREE_MODEL (store));
-
 	g_object_unref (G_OBJECT (store));
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (listview));
@@ -543,11 +532,6 @@ create_model (GtkWidget       *listview,
 	/* there should always be one line selected */
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
 
-	if (sel_format == NULL)
-		sf = get_selected_format (plugin);
-	else
-		sf = g_strdup (sel_format);
-	
 	/* add data to the list store */
 	while (formats[i] != NULL)
 	{
@@ -561,9 +545,9 @@ create_model (GtkWidget       *listview,
 				    COLUMN_FORMATS, str,
 				    COLUMN_INDEX, i,
 				    -1);
-		g_free (str);	
+		g_free (str);
 
-		if (strncmp (formats[i], sf, strlen (sf)) == 0)
+		if (sel_format && strcmp (formats[i], sel_format) == 0)
 			gtk_tree_selection_select_iter (selection, &iter);
 
 		++i;
@@ -576,12 +560,10 @@ create_model (GtkWidget       *listview,
 		gtk_tree_selection_select_iter (selection, &iter);
 	}
 
-	g_free (sf);
-
 	return GTK_TREE_MODEL (store);
 }
 
-static void 
+static void
 scroll_to_selected (GtkTreeView *tree_view)
 {
 	GtkTreeModel *model;
@@ -611,23 +593,24 @@ scroll_to_selected (GtkTreeView *tree_view)
 }
 
 static void
-create_formats_list (GtkWidget       *listview, 
+create_formats_list (GtkWidget       *listview,
 		     const gchar     *sel_format,
 		     GeditTimePlugin *plugin)
 {
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *cell;
-	
+
 	gedit_debug (DEBUG_PLUGINS);
 
 	g_return_if_fail (listview != NULL);
-	
+	g_return_if_fail (sel_format != NULL);
+
 	/* the Available formats column */
 	cell = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (
-			_("Available formats"), 
-			cell, 
-			"text", COLUMN_FORMATS, 
+			_("Available formats"),
+			cell,
+			"text", COLUMN_FORMATS,
 			NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (listview), column);
 
@@ -635,22 +618,22 @@ create_formats_list (GtkWidget       *listview,
 	create_model (listview, sel_format, plugin);
 
 	g_signal_connect (listview,
-			  "realize", 
-			  G_CALLBACK (scroll_to_selected), 
+			  "realize",
+			  G_CALLBACK (scroll_to_selected),
 			  NULL);
 
 	gtk_widget_show (listview);
 }
 
-static void 
-updated_custom_format_example (GtkEntry *format_entry, 
+static void
+updated_custom_format_example (GtkEntry *format_entry,
 			       GtkLabel *format_example)
 {
 	const gchar *format;
 	gchar *time;
 	gchar *str;
 	gchar *escaped_time;
-	
+
 	gedit_debug (DEBUG_PLUGINS);
 
 	g_return_if_fail (GTK_IS_ENTRY (format_entry));
@@ -660,9 +643,9 @@ updated_custom_format_example (GtkEntry *format_entry,
 
 	time = get_time (format);
 	escaped_time = g_markup_escape_text (time, -1);
-	
+
 	str = g_strdup_printf ("<span size=\"small\">%s</span>", escaped_time);
-	
+
 	gtk_label_set_markup (format_example, str);
 
 	g_free (escaped_time);
@@ -671,7 +654,7 @@ updated_custom_format_example (GtkEntry *format_entry,
 }
 
 static void
-choose_format_dialog_button_toggled (GtkToggleButton *button, 
+choose_format_dialog_button_toggled (GtkToggleButton *button,
 				     ChooseFormatDialog *dialog)
 {
 	gedit_debug (DEBUG_PLUGINS);
@@ -748,50 +731,16 @@ get_format_from_list (GtkWidget *listview)
 	{
 		gtk_tree_model_get (model, &iter, COLUMN_INDEX, &selected_value, -1);
 	}
-	
+
 	gedit_debug_message (DEBUG_PLUGINS, "Sel value: %d", selected_value);
 
         return selected_value;
 }
 
-static void
-ok_button_pressed (TimeConfigureDialog *dialog)
-{
-	gint sel_format;
-	const gchar *custom_format;
-
-	gedit_debug (DEBUG_PLUGINS);
-   
-	sel_format = get_format_from_list (dialog->list);
-   
-	custom_format = gtk_entry_get_text (GTK_ENTRY (dialog->custom_entry));
-	
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->custom)))
-	{
-		set_prompt_type (dialog->plugin, USE_CUSTOM_FORMAT);
-		set_custom_format (dialog->plugin, custom_format);
-	}
-	else 
-	{
-		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->use_list)))
-		{
-			set_prompt_type (dialog->plugin, USE_SELECTED_FORMAT);
-
-			set_selected_format (dialog->plugin, formats [sel_format]);
-		}
-		else
-     			/* Default to always prompt the user */
-			set_prompt_type (dialog->plugin, PROMPT_FOR_FORMAT);
-	}
-
-	gedit_debug_message (DEBUG_PLUGINS, "Sel: %d", sel_format);
-}
-
-static TimeConfigureDialog * 
+static TimeConfigureDialog *
 get_configure_dialog (GeditTimePlugin *plugin)
 {
 	TimeConfigureDialog *dialog = NULL;
-
 	GtkWidget *content;
 	GtkWidget *viewport;
 	GeditTimePluginPromptType prompt_type;
@@ -802,7 +751,7 @@ get_configure_dialog (GeditTimePlugin *plugin)
 	gedit_debug (DEBUG_PLUGINS);
 
 	dialog = g_new0 (TimeConfigureDialog, 1);
-	
+
 	dialog->dialog = gtk_dialog_new_with_buttons (_("Configure insert date/time plugin..."),
 						      NULL,
 						      GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -813,15 +762,15 @@ get_configure_dialog (GeditTimePlugin *plugin)
 						      GTK_STOCK_HELP,
 						      GTK_RESPONSE_HELP,
 						      NULL);
-						      
+
 	/* HIG defaults */
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog->dialog)), 5);
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox), 2); /* 2 * 5 + 2 = 12 */
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog->dialog)->action_area), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog->dialog)->action_area), 6);						      
-						      
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog->dialog)->action_area), 6);
+
 	g_return_val_if_fail (dialog->dialog != NULL, NULL);
-						      
+
 	ret = gedit_utils_get_glade_widgets (GEDIT_GLADEDIR "time.glade2",
 					     "time_dialog_content",
 					     &error_widget,
@@ -839,13 +788,13 @@ get_configure_dialog (GeditTimePlugin *plugin)
 	{
 		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox),
 					     error_widget);
-		gtk_container_set_border_width (GTK_CONTAINER (error_widget), 5);			     
+		gtk_container_set_border_width (GTK_CONTAINER (error_widget), 5);
 
 		gtk_widget_show (error_widget);
 
 		return dialog;
 	}
-	
+
 	gtk_window_set_resizable (GTK_WINDOW (dialog->dialog), FALSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog->dialog), FALSE);
 
@@ -884,30 +833,30 @@ get_configure_dialog (GeditTimePlugin *plugin)
 		gtk_widget_set_sensitive (dialog->custom_format_example, FALSE);
         }
 
-	updated_custom_format_example (GTK_ENTRY (dialog->custom_entry), 
+	updated_custom_format_example (GTK_ENTRY (dialog->custom_entry),
 			GTK_LABEL (dialog->custom_format_example));
-	
+
 	/* setup a window of a sane size. */
 	gtk_widget_set_size_request (GTK_WIDGET (viewport), 10, 200);
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox),
 			    content, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (content), 5);		     			    
+	gtk_container_set_border_width (GTK_CONTAINER (content), 5);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog),
 					 GTK_RESPONSE_OK);
 
 	g_signal_connect (dialog->custom,
 			  "toggled",
-			  G_CALLBACK (configure_dialog_button_toggled), 
+			  G_CALLBACK (configure_dialog_button_toggled),
 			  dialog);
    	g_signal_connect (dialog->prompt,
 			  "toggled",
-			  G_CALLBACK (configure_dialog_button_toggled), 
+			  G_CALLBACK (configure_dialog_button_toggled),
 			  dialog);
 	g_signal_connect (dialog->use_list,
 			  "toggled",
-			  G_CALLBACK (configure_dialog_button_toggled), 
+			  G_CALLBACK (configure_dialog_button_toggled),
 			  dialog);
 	g_signal_connect (dialog->dialog,
 			  "destroy",
@@ -915,7 +864,7 @@ get_configure_dialog (GeditTimePlugin *plugin)
 			  dialog);
 	g_signal_connect (dialog->custom_entry,
 			  "changed",
-			  G_CALLBACK (updated_custom_format_example), 
+			  G_CALLBACK (updated_custom_format_example),
 			  dialog->custom_format_example);
 
 	return dialog;
@@ -946,13 +895,9 @@ choose_format_dialog_row_activated (GtkTreeView        *list,
 
 	sel_format = get_format_from_list (dialog->list);
 	the_time = get_time (formats[sel_format]);
-			
-	g_free (dialog->plugin->priv->last_selected_format);		
-	dialog->plugin->priv->last_selected_format = g_strdup (formats[sel_format]);
 
-	dialog->plugin->priv->last_prompt_type = USE_SELECTED_FORMAT;
-	set_selected_format (dialog->plugin,
-			     dialog->plugin->priv->last_selected_format);
+	set_prompt_type (dialog->plugin, PROMPT_SELECTED_FORMAT);
+	set_selected_format (dialog->plugin, formats[sel_format]);
 
 	g_return_if_fail (the_time != NULL);
 
@@ -962,12 +907,14 @@ choose_format_dialog_row_activated (GtkTreeView        *list,
 }
 
 static ChooseFormatDialog *
-get_choose_format_dialog (GtkWindow       *parent,
-			  GeditTimePlugin *plugin)
+get_choose_format_dialog (GtkWindow                 *parent,
+			  GeditTimePluginPromptType  prompt_type,
+			  GeditTimePlugin           *plugin)
 {
 	ChooseFormatDialog *dialog;
 	GtkWidget *error_widget;
 	gboolean ret;
+	gchar *sf, *cf;
 
 	dialog = g_new0 (ChooseFormatDialog, 1);
 
@@ -993,30 +940,26 @@ get_choose_format_dialog (GtkWindow       *parent,
 		return NULL;
 	}
 
-	if (plugin->priv->last_selected_format == NULL)
-		plugin->priv->last_selected_format = get_selected_format (plugin);
+	sf = get_selected_format (plugin);
+	create_formats_list (dialog->list, sf, plugin);
+	g_free (sf);
 
-	create_formats_list (dialog->list, 
-			     plugin->priv->last_selected_format,
-			     plugin);
+	cf = get_custom_format (plugin);
+     	gtk_entry_set_text (GTK_ENTRY(dialog->custom_entry), cf);
+	g_free (cf);
 
-	if (plugin->priv->last_custom_format == NULL)
-		plugin->priv->last_custom_format = get_custom_format (plugin);
-	
-     	gtk_entry_set_text (GTK_ENTRY(dialog->custom_entry), 
-     			    plugin->priv->last_custom_format);
-	updated_custom_format_example (GTK_ENTRY (dialog->custom_entry), 
+	updated_custom_format_example (GTK_ENTRY (dialog->custom_entry),
 				       GTK_LABEL (dialog->custom_format_example));
 
-	if (plugin->priv->last_prompt_type == USE_CUSTOM_FORMAT)
+	if (prompt_type == PROMPT_CUSTOM_FORMAT)
 	{
         	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->custom), TRUE);
-		
+
 		gtk_widget_set_sensitive (dialog->list, FALSE);
 		gtk_widget_set_sensitive (dialog->custom_entry, TRUE);
 		gtk_widget_set_sensitive (dialog->custom_format_example, TRUE);
 	}
-	else
+	else if (prompt_type == PROMPT_SELECTED_FORMAT)
 	{
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->use_list), TRUE);
 
@@ -1024,6 +967,10 @@ get_choose_format_dialog (GtkWindow       *parent,
 		gtk_widget_set_sensitive (dialog->custom_entry, FALSE);
 		gtk_widget_set_sensitive (dialog->custom_format_example, FALSE);
 	}
+	else
+	{
+		g_return_val_if_reached (NULL);
+	}
 
 	/* setup a window of a sane size. */
 	gtk_widget_set_size_request (dialog->list, 10, 200);
@@ -1033,11 +980,11 @@ get_choose_format_dialog (GtkWindow       *parent,
 
 	g_signal_connect (dialog->custom,
 			  "toggled",
-			  G_CALLBACK (choose_format_dialog_button_toggled), 
+			  G_CALLBACK (choose_format_dialog_button_toggled),
 			  dialog);
 	g_signal_connect (dialog->use_list,
 			  "toggled",
-			  G_CALLBACK (choose_format_dialog_button_toggled), 
+			  G_CALLBACK (choose_format_dialog_button_toggled),
 			  dialog);
 	g_signal_connect (dialog->dialog,
 			  "destroy",
@@ -1045,7 +992,7 @@ get_choose_format_dialog (GtkWindow       *parent,
 			  dialog);
 	g_signal_connect (dialog->custom_entry,
 			  "changed",
-			  G_CALLBACK (updated_custom_format_example), 
+			  G_CALLBACK (updated_custom_format_example),
 			  dialog->custom_format_example);
 	g_signal_connect (dialog->list,
 			  "row_activated",
@@ -1058,15 +1005,15 @@ get_choose_format_dialog (GtkWindow       *parent,
 }
 
 static void
-choose_format_dialog_response_cb (GtkWidget          *widget, 
-				  gint                response, 
+choose_format_dialog_response_cb (GtkWidget          *widget,
+				  gint                response,
 				  ChooseFormatDialog *dialog)
 {
 	switch (response)
 	{
 		case GTK_RESPONSE_HELP:
 		{
-			gedit_debug_message (DEBUG_PLUGINS, "GTK_RESPONSE_HELP");	
+			gedit_debug_message (DEBUG_PLUGINS, "GTK_RESPONSE_HELP");
 			gedit_help_display (GTK_WINDOW (widget),
 					    "gedit.xml",
 					    "gedit-insert-date-time-plugin");
@@ -1077,52 +1024,44 @@ choose_format_dialog_response_cb (GtkWidget          *widget,
 			gchar *the_time;
 
 			gedit_debug_message (DEBUG_PLUGINS, "GTK_RESPONSE_OK");
-						
+
 			/* Get the user's chosen format */
 			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->use_list)))
 			{
 				gint sel_format;
-						
+
 				sel_format = get_format_from_list (dialog->list);
 				the_time = get_time (formats[sel_format]);
-						
-				g_free (dialog->plugin->priv->last_selected_format);		
-				dialog->plugin->priv->last_selected_format = g_strdup (formats[sel_format]);
 
-				dialog->plugin->priv->last_prompt_type = USE_SELECTED_FORMAT;
-				set_selected_format (dialog->plugin,
-						     dialog->plugin->priv->last_selected_format);
+				set_prompt_type (dialog->plugin, PROMPT_SELECTED_FORMAT);
+				set_selected_format (dialog->plugin, formats[sel_format]);
 			}
 			else
 			{
 				const gchar *format;
-						
+
 				format = gtk_entry_get_text (GTK_ENTRY (dialog->custom_entry));
 				the_time = get_time (format);
 
-				g_free (dialog->plugin->priv->last_custom_format);					
-				dialog->plugin->priv->last_custom_format = g_strdup (format);
-
-				dialog->plugin->priv->last_prompt_type = USE_CUSTOM_FORMAT;
-				set_custom_format (dialog->plugin,
-						   dialog->plugin->priv->last_custom_format);
+				set_prompt_type (dialog->plugin, PROMPT_CUSTOM_FORMAT);
+				set_custom_format (dialog->plugin, format);
 			}
 
 			g_return_if_fail (the_time != NULL);
 
 			real_insert_time (dialog->buffer, the_time);
 			g_free (the_time);
-		
+
 			gtk_widget_destroy (dialog->dialog);
 			break;
-		}	
+		}
 		case GTK_RESPONSE_CANCEL:
 			gedit_debug_message (DEBUG_PLUGINS, "GTK_RESPONSE_CANCEL");
 			gtk_widget_destroy (dialog->dialog);
-	}	
+	}
 }
 
-static void 
+static void
 time_cb (GtkAction  *action,
 	 ActionData *data)
 {
@@ -1153,13 +1092,14 @@ time_cb (GtkAction  *action,
         {
         	GtkWindowGroup *wg;
 		ChooseFormatDialog *dialog;
-		
+
 		dialog = get_choose_format_dialog (GTK_WINDOW (data->window),
+						   prompt_type,
 						   data->plugin);
 		g_return_if_fail (dialog != NULL);
 
 		wg = gedit_window_get_group (data->window);
-		
+
 		gtk_window_group_add_window (wg,
 				     	     GTK_WINDOW (dialog->dialog));
 
@@ -1169,7 +1109,7 @@ time_cb (GtkAction  *action,
 
 		dialog->buffer = buffer;
 		dialog->plugin = data->plugin;
-		
+
 		g_signal_connect (dialog->dialog,
 				  "response",
 				  G_CALLBACK (choose_format_dialog_response_cb),
@@ -1188,8 +1128,39 @@ time_cb (GtkAction  *action,
 }
 
 static void
-configure_dialog_response_cb (GtkWidget           *widget, 
-			      gint                 response, 
+ok_button_pressed (TimeConfigureDialog *dialog)
+{
+	gint sel_format;
+	const gchar *custom_format;
+
+	gedit_debug (DEBUG_PLUGINS);
+
+	sel_format = get_format_from_list (dialog->list);
+
+	custom_format = gtk_entry_get_text (GTK_ENTRY (dialog->custom_entry));
+
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->custom)))
+	{
+		set_prompt_type (dialog->plugin, USE_CUSTOM_FORMAT);
+		set_custom_format (dialog->plugin, custom_format);
+	}
+	else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->use_list)))
+	{
+		set_prompt_type (dialog->plugin, USE_SELECTED_FORMAT);
+		set_selected_format (dialog->plugin, formats [sel_format]);
+	}
+	else
+	{
+		/* Default to prompt the user with the list selected */
+		set_prompt_type (dialog->plugin, PROMPT_SELECTED_FORMAT);
+	}
+
+	gedit_debug_message (DEBUG_PLUGINS, "Sel: %d", sel_format);
+}
+
+static void
+configure_dialog_response_cb (GtkWidget           *widget,
+			      gint                 response,
 			      TimeConfigureDialog *dialog)
 {
 	switch (response)
@@ -1206,12 +1177,12 @@ configure_dialog_response_cb (GtkWidget           *widget,
 		case GTK_RESPONSE_OK:
 		{
 			gedit_debug_message (DEBUG_PLUGINS, "GTK_RESPONSE_OK");
-		
+
 			ok_button_pressed (dialog);
-			
+
 			gtk_widget_destroy (dialog->dialog);
 			break;
-		}	
+		}
 		case GTK_RESPONSE_CANCEL:
 		{
 			gedit_debug_message (DEBUG_PLUGINS, "GTK_RESPONSE_CANCEL");
@@ -1226,18 +1197,17 @@ impl_create_configure_dialog (GeditPlugin *plugin)
 	TimeConfigureDialog *dialog;
 
 	dialog = get_configure_dialog (GEDIT_TIME_PLUGIN (plugin));
-	
+
 	dialog->plugin = GEDIT_TIME_PLUGIN (plugin);
-		
+
 	g_signal_connect (dialog->dialog,
 			  "response",
 			  G_CALLBACK (configure_dialog_response_cb),
 			  dialog);
-			  
+
 	return GTK_WIDGET (dialog->dialog);
 }
 
-
 static void
 gedit_time_plugin_class_init (GeditTimePluginClass *klass)
 {
